function shuffled = adb_shufflemap(ordered)

%randomly shuffle order of rows in a given map: if one or both of a pair of
%maps are disordered, this means that despite the map overall having the
%same shape, the correspondence between the points will be disrupted.
%
%If multiubject data is used (i.e. in a cell array), each map is shuffled
%individually.
%
% Code written by Andrew D Bard, 2015, for Liewe et al, PloS one, 2015.
% Contact: andrew.bard@kcl.ac.uk, andrew.lowe@kcl.ac.uk

if isnumeric(ordered)
    n_points =size(ordered,1);    
    shuffled = ordered(randperm(n_points),:);
elseif iscell(ordered)
    shuffled = cellfun(@adb_shufflemap,ordered,'uni',0);
end

end