function LGNcells = asl_collapse_column(name,LGNcells, LGNborders, exclude_list)


num_col = length(LGNcells);

fprintf('\nCollapsing each column along spline\n\n');
fig1=figure;
vec = zeros(3,2);
n=0;
for l=1:num_col
    if isempty(find(l==exclude_list))
        % find vector of starting 10th percentile of splined column
        vec = vec + asl_find_col(LGNcells(l).spline_col);
        n=n+1;
    end
end
vec=vec/n;

for l=1:num_col
    if isempty(find(l==exclude_list))
        fprintf('\t%d',l);
        % find vector of starting 10th percentile of splined column
        %  vec = asl_find_col(LGNcells(l).spline_col);
        % transform reference space
        LGNcells(l).vec = vec;
        [LGNcells(l).straightened_column, LGNcells(l).collapsed_column]  = asl_straighten_col(LGNcells(l).LGNxyz,LGNcells(l).spline_col,vec);
        % double check
        
        [S v] = alphavol(LGNborders,inf,1); hold on;
        plot3(LGNcells(l).spline_col(:,1),LGNcells(l).spline_col(:,2),LGNcells(l).spline_col(:,3),'r.');
        plot3(LGNcells(l).LGNxyz(:,1),LGNcells(l).LGNxyz(:,2),LGNcells(l).LGNxyz(:,3),'kx');
        
        plot3(LGNcells(l).straightened_column(:,1),LGNcells(l).straightened_column(:,2),LGNcells(l).straightened_column(:,3),'go');
        title([name,'-',num2str(l),' straightened to Average 0-20% of all columns']);
        filename =[name,'_straightened_col_',num2str(l),'.png'];
        print('-dpng','-r300', filename);
        clf;
    end
end

fprintf('\nDone\n\n');
close(fig1);
end

function vec = asl_find_col(spline_col)

% simple for now but could fit straight line to 0-20 %tile points

vec = zeros(3,2);
n=1;%round(size(spline_col,1)*0.4);
vec(:,1)=spline_col(n,:);
n=round(size(spline_col,1)*0.2);
vec(:,2)=spline_col(n,:);

end

function [straightened, collapsed] = asl_straighten_col(cells,col,vec)

position=[0,1];
% transform reference space so col is z
s=vec(:,2)-vec(:,1);
w=s./norm(s);
a=cross(w,[0;0;1]);
v=a./norm(a);
u=cross(v,w);

M = [u(1),u(2),u(3),0;v(1),v(2),v(3),0;w(1),w(2),w(3),0;0,0,0,1];
T = [1,0,0,-vec(1,1);0,1,0,-vec(2,1);0,0,1,-vec(3,1);0,0,0,1];
iT = [1,0,0,vec(1,1);0,1,0,vec(2,1);0,0,1,vec(3,1);0,0,0,1];

ncells = zeros(4,size(cells,1));
old_cells = ones(4,size(cells,1));
old_cells(1:3,:)=cells.';

ncol = zeros(4,size(col,1));
old_col = ones(4,size(col,1));
old_col(1:3,:)=col.';

for l=1:size(ncells,2)
    ncells(:,l) = (M*(T*old_cells(:,l)));
end

for l=1:size(ncol,2)
    ncol(:,l) = (M*(T*old_col(:,l)));
end

%correct for dist offset

pos=min(ncol(3,:));
ncol(3,:)=ncol(3,:)-pos;
ncells(3,:)=ncells(3,:)-pos;

d=zeros(size(ncol,2),1);
for dl=2:size(ncol,2)
    d(dl)=d(dl-1)+sqrt((ncol(1,dl)-ncol(1,dl-1))^2 +(ncol(2,dl)-ncol(2,dl-1))^2 +(ncol(3,dl)-ncol(3,dl-1))^2);
end
[dstart,mi] = find(d<=d(end)*position(1));
dstart = dstart(end);

[dend,mi] = find(d<=d(end)*position(2));
dend=dend(end);

straightened = ones(4,size(ncells,2));
collapsed = ones(size(ncells,2),5);
cc=1;
for nc=1:size(ncells,2)
    dist=sqrt((ncells(1,nc).'-ncol(1,:)).^2 + ...
        (ncells(2,nc).'-ncol(2,:)).^2 + ...
        (ncells(3,nc).'-ncol(3,:)).^2);
    [m, mi] = min(dist); % check does right thing mi should = position in 2nd dimension
    
    
    if mi>=dstart && mi<=dend
        % calculate dist from LGNcells(l).spline_col(1,3) to LGNcells(l).spline_col(mi,3)
        d=0;
        for dl=2:mi
            d=d+sqrt((ncol(1,dl)-ncol(1,dl-1))^2 +(ncol(2,dl)-ncol(2,dl-1))^2 +(ncol(3,dl)-ncol(3,dl-1))^2);
        end
        if position(1) <= 0.5
            straightened(1:2,cc) = ncells(1:2,nc)+(ncol(1:2,dstart) - ncol(1:2,mi));
        else
            straightened(1:2,cc) = ncells(1:2,nc)+(ncol(1:2,dend) - ncol(1:2,mi));
        end
        
        straightened(3,cc) = d+pos;
        collapsed(cc,1:2)=straightened(1:2,cc); % mipped xy position
        collapsed(cc,3)=mi; % position on splined col - length
        collapsed(cc,4)=d; % distance from start of col
        collapsed(cc,5)=m; % distance from column
        cc=cc+1;
    end
end

straightened = straightened(:,1:cc-1);

% untransform
temp=straightened;

% Return to original coordinate system

for l=1:size(temp,2)
    temp(:,l) = (iT)*((M.')*straightened(:,l));
end

straightened=temp(1:3,:).';

end
