function LGNcells = asl_make_projections_map(name,LGNcells, LGNborders, code, exclude_list)

num_col = length(LGNcells);

fig1 = figure;

%create a mesh based on the border points
[S v] = alphavol(LGNborders,inf,1); hold on;
fprintf('\nStarting spline fit for each column\n\n');
for l=1:num_col
    if isempty(find(l==exclude_list))
        fprintf('\b\t%d',l);

        % Clever bit - create splined fit through cells and find where it joins
        % the border.
        [LGNcells(l).spline_col LGNcells(l).pp LGNcells(l).vec] = asl_spline_col(LGNcells(l).LGNxyz,LGNborders,[LGNcells(l).percentile_col_yz(1,:).',LGNcells(l).percentile_col_yz(9,:).']);
        
        % plot the fitted column and start and end points on the boundary
        plot3(LGNcells(l).spline_col(:,1),LGNcells(l).spline_col(:,2),LGNcells(l).spline_col(:,3),'b','Linewidth',2);
        scatter3(LGNcells(l).spline_col(1,1),LGNcells(l).spline_col(1,2),LGNcells(l).spline_col(1,3),40,'g','filled');
        scatter3(LGNcells(l).spline_col(end,1),LGNcells(l).spline_col(end,2),LGNcells(l).spline_col(end,3),40,'r','filled');
        % Can use this to look at each coloumn in turn
        %   j=input('continue');
        
    end
end

if code==1 %wt
    xlim([0 1400])
    ylim([300,2000])
    zlim([200,2000])
    
end
if code == 2    %p6
    ylim([100,1200])
    xlim([0 1000])
    zlim([0,1400])
end
if code == 3 %P12
    xlim([0 1200])
    ylim([100,1400])
    zlim([0,1600])
end
view(0,0); % plan LM_PA
filename =[name,'_LM_PA.png'];
print('-dpng','-r300', filename);
filename =[name,'_LM_PA.fig'];
savefig(filename);
view(-90,180); % rotated side view DV_AP
filename =[name,'_DV_AP.png'];
print('-dpng','-r300', filename);
filename =[name,'_DV_AP.fig'];
savefig(filename);
view(0,-90); % Coronal LM_VD
filename =[name,'_LM_VD.png'];
print('-dpng','-r300', filename);
filename =[name,'_LM_VD.fig'];
savefig(filename);
fprintf('\nDone\n\n');
end


function [spline_col, pp, vec] = asl_spline_col(xyz,borders,vec)
% transform to new coordinate system then splines along z (column length)
%
% Also extends out the spline to find the dLGN boundary.
%
%


% Tranform into new coordinate system

% vec = position of outer percentiles used as reference frame
s=vec(:,2)-vec(:,1);
w=s./norm(s);
a=cross(w,[0;0;1]);
v=a./norm(a);
u=cross(v,w);

M = [u(1),u(2),u(3),0;v(1),v(2),v(3),0;w(1),w(2),w(3),0;0,0,0,1];
T = [1,0,0,-vec(1,1);0,1,0,-vec(2,1);0,0,1,-vec(3,1);0,0,0,1];
iT = [1,0,0,vec(1,1);0,1,0,vec(2,1);0,0,1,vec(3,1);0,0,0,1];

ncoords = zeros(4,size(xyz,1));
xyz = xyz.';
old_coords = ones(4,size(ncoords,2));
old_coords(1:3,:)=xyz;

for l=1:size(ncoords,2)
    ncoords(:,l) = (M*(T*old_coords(:,l)));
end


% Transform borders into the same reference frame
nborders = zeros(4,size(borders,1));
old_borders = ones(4,size(nborders,2));
old_borders(1:3,:)=borders.';

for l=1:size(nborders,2)
    nborders(:,l) = (M*(T*old_borders(:,l)));
end

% spline along column ( now Z axis)
pp=splinefit(ncoords(3,:),ncoords(1:2,:),5,2);

% Extend out spline
Z = linspace(min(nborders(3,:)),max(nborders(3,:)),2000);
XY = ppval(pp,Z);

% Smooth out kinks
XY(1,:)=imgaussian(XY(1,:),100);
XY(2,:)=imgaussian(XY(2,:),100);
%Z=imgaussian(Z,200);

% Find points on boundary
% Convert to triangular surface with smal triangles so can use sentre of
% mass to find intersection between triangular plane and column
[triHull, vbOutside, vbInside] =AlphaHull(nborders(1:3,:).',100);

% Debug 
%trisurf(triHull,nborders(1,:),nborders(2,:),nborders(3,:),'FaceColor','green','FaceAlpha',0.5) 

% Calculate centre of mass for each triangle.
tricom = zeros(size(triHull));
for cl=1:size(triHull,1)
    tricom(cl,1) = mean(nborders(1,[triHull(cl,:)]));
    tricom(cl,2) = mean(nborders(2,[triHull(cl,:)]));
    tricom(cl,3) = mean(nborders(3,[triHull(cl,:)]));
end

% Calculate euclidean distance for each cell to all point on splined col.
cell_euclidean_dist = zeros(2000,size(ncoords,2));
for cl=1:2000
    cell_euclidean_dist(cl,:) = sqrt((XY(1,cl)-ncoords(1,:)).^2 + (XY(2,cl)-ncoords(2,:)).^2 + (Z(cl)-ncoords(3,:)).^2);
end

% Find Euclidean distance from all points on line to all tricom points
euclidean_dist = zeros(2000,size(triHull,1));
for cl=1:2000
    euclidean_dist(cl,:) = sqrt((XY(1,cl)-tricom(:,1)).^2 + (XY(2,cl)-tricom(:,2)).^2 + (Z(cl)-tricom(:,3)).^2);
end

% Find ends of column to out from to both ends


[m,kk1]=min(cell_euclidean_dist(:,find(ncoords(3,:)==min(ncoords(3,:)))));

[m,kk2]=min(cell_euclidean_dist(:,find(ncoords(3,:)==max(ncoords(3,:)))));

% look for border just inside column 
length_col = kk2-kk1; offset = round(length_col*0.25);
kk1=kk1+offset;
kk2=kk2-offset;

% Look beyond ends for border
[e, mi, mii] = find(euclidean_dist(1:kk1,:)==min(min(euclidean_dist(1:kk1,:),[],2)));
[s, mi, mii] = find(euclidean_dist(kk2+1:2000,:)==min(min(euclidean_dist(kk2+1:2000,:))));
s=s+kk2;

% Double Check still inside borders P6 is a doughnut!
if Z(e)<min(ncoords(3,:))
    [m,e]=min(abs(Z-min(ncoords(3,:))));
end
if Z(s)>max(ncoords(3,:))
    [m,s]=min(abs(Z-max(ncoords(3,:))));
end

% Find outermost points

XY=XY(:,e:s);
Z=Z(e:s);

old_coords=ones(4,numel(Z));
old_coords(1:2,:)=XY;
old_coords(3,:)=Z;

% Return to original coordinate system

for l=1:size(old_coords,2)
    ncoords(:,l) = (iT)*((M.')*old_coords(:,l));
end

spline_col=ncoords(1:3,:).';


end
