function group = asl_summarise_col(LGNcells,exclude_list, ttitle, sf)
% sf - is an optional linear scaling factor to compensate for the different 
%   volumes of the dLGN across ages.

if exist('sf','var')==0
    sf = 1;
end

group = struct;

group.dist_from_col = [];

group.pos_on_col = [];

group.length_col = [];

group.col_length_bins = 0:0.05:1;
group.num_cells_col_binned = zeros(numel(group.col_length_bins),28);

num_cols = 1;
for l=1:numel(LGNcells)
if numel(find(exclude_list==l))==0
ndist = LGNcells(l).collapsed_column(:,4)/LGNcells(l).length_col;
group.pos_on_col = [group.pos_on_col; ndist];
group.dist_from_col = [group.dist_from_col; LGNcells(l).collapsed_column(:,5)];
group.length_col = [group.length_col; LGNcells(l).length_col];
group.num_cells_col_binned(:,num_cols) = histc(ndist, group.col_length_bins);
num_cols = num_cols + 1;
end
end
num_cols = num_cols - 1;


group.mean_num_cells_col_binned = mean(group.num_cells_col_binned(:,1:num_cols),2);
group.std_num_cells_col_binned = std(group.num_cells_col_binned(:,1:num_cols),1,2);

figure; bar(group.col_length_bins(1:end-1)+group.col_length_bins(2)/2,group.mean_num_cells_col_binned(1:end-1)); hold on;
errorbar(group.col_length_bins(1:end-1)+group.col_length_bins(2)/2,group.mean_num_cells_col_binned(1:end-1),group.std_num_cells_col_binned(1:end-1)/sqrt(num_cols));
title(ttitle);

group.mean_dist_from_col_binned = zeros(numel(group.col_length_bins)-1,1);
group.std_dist_from_col_binned = zeros(numel(group.col_length_bins)-1,1);



for l=2:numel(group.col_length_bins)
    switch l
        case 2    
            [ind, t] = find(group.pos_on_col>group.col_length_bins(l-1) & group.pos_on_col<group.col_length_bins(l));
        case numel(group.col_length_bins)
            [ind, t] = find(group.pos_on_col>=group.col_length_bins(l-1) & group.pos_on_col<=group.col_length_bins(l));
        otherwise
            [ind, t] = find(group.pos_on_col>=group.col_length_bins(l-1) & group.pos_on_col<group.col_length_bins(l));
    end
   % group.num_cells_col_binned(l-1) = numel(ind);
    group.mean_dist_from_col_binned(l-1) = mean(group.dist_from_col(ind));
    group.std_dist_from_col_binned(l-1) = std(group.dist_from_col(ind));
end

figure; bar((group.col_length_bins(1:end-1)+group.col_length_bins(2)/2),group.mean_dist_from_col_binned*sf); hold on
errorbar((group.col_length_bins(1:end-1)+group.col_length_bins(2)/2),group.mean_dist_from_col_binned*sf,sf*group.std_dist_from_col_binned/sqrt(num_cols)); 
title(ttitle);

group.dist_from_col_bins = 0:5:400;
group.binned_dist_from_col = histc(group.dist_from_col*sf,group.dist_from_col_bins);

figure; bar(group.dist_from_col_bins,group.binned_dist_from_col/num_cols,'histc');
title(ttitle);

end


